.. _cli-introduction:

##################
Command line tool
##################

When you install the `anemoi-datasets` package, this will also install command line tool
called ``anemoi-datasets`` which can be used to manage the zarr datasets.

The tool can provide help with the ``--help`` options:

.. code-block:: bash

    % anemoi-datasets --help

The commands are:

- :ref:`Create Command <create_command>`
- :ref:`Copy Command <copy_command>`
- :ref:`Inspect Command <Inspect_command>`
- :ref:`Compare Command <compare_command>`
- :ref:`Scan Command <scan_command>`
- :ref:`Compare LAM Command <compare_lam_command>`
